/*
 *  Copyright (c) 2016, Sean Jensen.
 *  
 *  See file LICENSE for license terms.
 *
 */

#ifndef NKRO_h
#define NKRO_h

#include <HID.h>

#include "XTUSBMAP.h"


/*
 * The Arduino USB library expects descriptors to be alloced in PROGMEM.
 * (See USBDesc.cpp library.)
 * 
 * Also, the Arduino HID library only allows for sending reports with
 * a REPORT_ID.
 * 
 * The report is simply a bit-vector showing which USB HID usage codes (`keycodes') are
 * active. Thus, any combination of simultaneous usage codes can be represented
 * and sent to the USB host.
 * 
 */
 
const unsigned char XT_REPORTDESCRIPTOR[25] PROGMEM = {
    0x05, 0x01,                    // USAGE_PAGE (Generic Desktop)
    0x09, 0x06,                    // USAGE (Keyboard)
    0xa1, 0x01,                    // COLLECTION (Application)
    0x85, 0x02,                    //   REPORT_ID(2)
    0x05, 0x07,                    //   USAGE_PAGE (Keyboard)
    0x19, 0x00,                    //   USAGE_MINIMUM (Reserved (no event indicated))
    0x29, 0xe7,                    //   USAGE_MAXIMUM (Keyboard Right GUI)
    0x15, 0x00,                    //   LOGICAL_MINIMUM (0)
    0x25, 0x01,                    //   LOGICAL_MAXIMUM (1)
    0x75, 0x01,                    //   REPORT_SIZE (1)
    0x95, 0xe8,                    //   REPORT_COUNT (232) 232 bits = 29 bytes.
    0x81, 0x02,                    //   INPUT (Data,Var,Abs)
    0xc0                           // END_COLLECTION
} ;


/*
 * The HID specification defines 232 usage codes, so we need a 232-bit vector.
 * 232 bits is (conveniently) exactly 29 bytes.
 * 
 */

unsigned char XT_REPORT[29] = {
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x00, 0x00, 0x00, 0x00, 0x00
} ;


/*
 *  This is how the Arduino HID library is made aware of our report descriptor
 *  
 */

HIDSubDescriptor XT_NODE(XT_REPORTDESCRIPTOR, sizeof XT_REPORTDESCRIPTOR) ;

/*
 *  The following macros hide the details of the Arduino HID API calls.
 *  It should be possible to redefine them to suit other HID libraries.
 *  
 */

#define ATTACH_SUBDESCRIPTOR() HID().AppendDescriptor(&XT_NODE)

#define SEND() HID().SendReport(2,XT_REPORT, sizeof XT_REPORT)


#endif


