/*
 *  Copyright (c) 2016, Sean Jensen.
 *  
 *  See file LICENSE for license terms.
 *
 */

#ifndef XTUSBMAP_h
#define XTUSBMAP_h

/*
 *  This table translates XT scancodes (or `positions') into
 *  USB keycodes (or `usages'). If you want an exotic layout,
 *  here is where you can achieve that. For XT scancode i,
 *  store the desired USB usage code at position [i] in the array.
 *  
 *  See the `Universal Serial Bus HID Usage Tables' document, pp 53-60
 *  for a complete list of all possible keyboard Usage codes that
 *  the USB spec supports.
 *  
 */

const unsigned char XT_HID_ID[84] = {    
  0x00,    // Position 00 Unused
  0x29,    // Position 01 Esc 
  0x1E,    // Position 02 1 !
  0x1F,    // Position 03 2 @
  0x20,    // Position 04 3 #
  0x21,    // Position 05 4 $
  0x22,    // Position 06 5 %
  0x23,    // Position 07 6 ^
  0x24,    // Position 08 7 &
  0x25,    // Position 09 8 *
  0x26,    // Position 10 9 (
  0x27,    // Position 11 0 )
  0x2D,    // Position 12 - _
  0x2E,    // Position 13 = +
  0x2A,    // Position 14 Backspace
  0x2B,    // Position 15 Tab
  0x14,    // Position 16 Q
  0x1A,    // Position 17 W
  0x08,    // Position 18 E
  0x15,    // Position 19 R
  0x17,    // Position 20 T
  0x1C,    // Position 21 Y
  0x18,    // Position 22 U
  0x0C,    // Position 23 I
  0x12,    // Position 24 O
  0x13,    // Position 25 P
  0x2F,    // Position 26 [ {
  0x30,    // Position 27 ] }
  0x28,    // Position 28 Return
  0xE0,    // Position 29 Ctrl
  0x04,    // Position 30 A
  0x16,    // Position 31 S
  0x07,    // Position 32 D
  0x09,    // Position 33 F
  0x0A,    // Position 34 G
  0x0B,    // Position 35 H
  0x0D,    // Position 36 J
  0x0E,    // Position 37 K
  0x0F,    // Position 38 L
  0x33,    // Position 39 ; :
  0x34,    // Position 40 ' "
  0x35,    // Position 41 ` ~
  0xE1,    // Position 42 Left Shift
  0x31,    // Position 43 \ |
  0x1D,    // Position 44 Z
  0x1B,    // Position 45 X
  0x06,    // Position 46 C
  0x19,    // Position 47 V
  0x05,    // Position 48 B
  0x11,    // Position 49 N
  0x10,    // Position 50 M
  0x36,    // Position 51 , <
  0x37,    // Position 52 . >
  0x38,    // Position 53 / ?
  0xE5,    // Position 54 Right Shift
  0x46,    // Position 55 PrtSc
  0xE2,    // Position 56 Alt
  0x2C,    // Position 57 Space
  0x39,    // Position 58 Caps Lock
  0x3A,    // Position 59 F1
  0x3B,    // Position 60 F2
  0x3C,    // Position 61 F3
  0x3D,    // Position 62 F4
  0x3E,    // Position 63 F5
  0x3F,    // Position 64 F6
  0x40,    // Position 65 F7
  0x41,    // Position 66 F8
  0x42,    // Position 67 F9
  0x43,    // Position 68 F10
  0x53,    // Position 69 Num Lock
  0x47,    // Position 70 Scroll Lock
  0x5F,    // Position 71 Home 7
  0x60,    // Position 72 Up 8
  0x61,    // Position 73 PgUp 9
  0x56,    // Position 74 -
  0x5C,    // Position 75 Left 4
  0x5D,    // Position 76 5
  0x5E,    // Position 77 Right 6
  0x57,    // Position 78 +
  0x59,    // Position 79 End 1
  0x5A,    // Position 80 Down 2
  0x5B,    // Position 81 PgDn 3
  0x62,    // Position 82 Ins 0
  0x63     // Position 83 Del .
} ;

#endif


